print("import: 'social_core'")
import social_core

print("import: 'social_core.backends'")
import social_core.backends

